@@ -4,7 +4,7 @@
 
 Copyright (c) 1999-2003 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: echo.py,v 1.4 2003/06/30 06:25:19 ngps Exp $'
+RCS_id='$Id: echo.py 299 2005-06-09 17:32:28Z heikki $'
 
 import getopt, sys
 from socket import gethostname
@@ -24,8 +24,8 @@ Rand.load_file('../randpool.dat', -1)
 
 ctx = SSL.Context('sslv3')
 ctx.load_cert_chain('client.pem')
-ctx.set_verify(SSL.verify_none, 10)
-#ctx.set_verify(SSL.verify_peer, 10, SSL.cb.ssl_verify_callback)
+#ctx.set_verify(SSL.verify_none, 10)
+ctx.set_verify(SSL.verify_peer, 10, SSL.cb.ssl_verify_callback)
 ctx.load_verify_locations('ca.pem')
 #ctx.set_allow_unknown_ca(1)
 ctx.set_info_callback()
